==> apache-doris-3.0.8-rc01-src.tar.gz: apache-doris-3.0.8-rc01-src/be/src/http/action/jeprofile_actions.h <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

#pragma once

#include "http/http_handler.h"
#include "http/http_handler_with_auth.h"

namespace doris {

class HttpRequest;
class ExecEnv;

class SetJeHeapProfileActiveActions final : public HttpHandlerWithAuth {
public:
    SetJeHeapProfileActiveActions(ExecEnv* exec_env) : HttpHandlerWithAuth(exec_env) {}
    ~SetJeHeapProfileActiveActions() override = default;
    void handle(HttpRequest* req) override;
};

class DumpJeHeapProfileToDotActions final : public HttpHandlerWithAuth {
public:
    DumpJeHeapProfileToDotActions(ExecEnv* exec_env) : HttpHandlerWithAuth(exec_env) {}
    ~DumpJeHeapProfileToDotActions() override = default;
    void handle(HttpRequest* req) override;
};

class DumpJeHeapProfileActions final : public HttpHandlerWithAuth {
public:
    DumpJeHeapProfileActions(ExecEnv* exec_env) : HttpHandlerWithAuth(exec_env) {}
    ~DumpJeHeapProfileActions() override = default;
    void handle(HttpRequest* req) override;
};

} // namespace doris

==> apache-doris-4.0.2-rc02-src.tar.gz: apache-doris-4.0.2-rc02-src/be/src/http/action/jeprofile_actions.h <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

#pragma once

#include "http/http_handler.h"
#include "http/http_handler_with_auth.h"

namespace doris {

class HttpRequest;
class ExecEnv;

class SetJeHeapProfileActiveActions final : public HttpHandlerWithAuth {
public:
    SetJeHeapProfileActiveActions(ExecEnv* exec_env) : HttpHandlerWithAuth(exec_env) {}
    ~SetJeHeapProfileActiveActions() override = default;
    void handle(HttpRequest* req) override;
};

class SetJeHeapProfileResetActions final : public HttpHandlerWithAuth {
public:
    SetJeHeapProfileResetActions(ExecEnv* exec_env) : HttpHandlerWithAuth(exec_env) {}
    ~SetJeHeapProfileResetActions() override = default;
    void handle(HttpRequest* req) override;
};

class DumpJeHeapProfileToDotActions final : public HttpHandlerWithAuth {
public:
    DumpJeHeapProfileToDotActions(ExecEnv* exec_env) : HttpHandlerWithAuth(exec_env) {}
    ~DumpJeHeapProfileToDotActions() override = default;
    void handle(HttpRequest* req) override;
};

class DumpJeHeapProfileActions final : public HttpHandlerWithAuth {
public:
    DumpJeHeapProfileActions(ExecEnv* exec_env) : HttpHandlerWithAuth(exec_env) {}
    ~DumpJeHeapProfileActions() override = default;
    void handle(HttpRequest* req) override;
};

} // namespace doris
